<?php
/*
 * Entities to be used in all sources
 */

class Entity {
	public $id;
}


###################################################################################################
###   ENTRY   #####################################################################################

define('ENTRY_TYPE_START_ONLY',			1);
define('ENTRY_TYPE_START_AND_FINISH',	2);
define('ENTRY_TYPE_TIMESPAN',			3);

define('ENTRY_STATUS_PENDING',	1);
define('ENTRY_STATUS_APPROVED',	2);
define('ENTRY_STATUS_REJECTED',	3);

class Entry extends Entity {
	public $date;
	public $startTime;
	public $endTime;
	public $timeSpan;
	public $description;
	public $type;
	public $checkDate;
	public $checkDateIp;
	public $checkStartTime;
	public $checkStartTimeIp;
	public $checkEndTime;
	public $checkEndTimeIp;
	public $status;
	public $statusDate;
	public $note;
	public $projectId;
	public $userId;
	public $taskId;
	
	function loadFromSQL($row) {
		$this->id				=	htmlentities(stripslashes($row['entry_id']));
		$this->date				=	htmlentities(stripslashes($row['entry_date']));
		$this->startTime		=	htmlentities(stripslashes($row['entry_starttime']));
		$this->endTime			=	htmlentities(stripslashes($row['entry_endtime']));
		$this->timeSpan			=	htmlentities(stripslashes($row['entry_timespan']));
		$this->description		=	htmlentities(stripslashes($row['entry_description']));
		$this->type				=	htmlentities(stripslashes($row['entry_type']));
		$this->checkDate		=	htmlentities(stripslashes($row['entry_check_date']));
		$this->checkDateIp		=	htmlentities(stripslashes($row['entry_check_date_ip']));
		$this->checkStartTime	=	htmlentities(stripslashes($row['entry_check_starttime']));
		$this->checkStartTimeIp	=	htmlentities(stripslashes($row['entry_check_starttime_ip']));
		$this->checkEndTime		=	htmlentities(stripslashes($row['entry_check_endtime']));
		$this->checkEndTimeIp	=	htmlentities(stripslashes($row['entry_check_endtime_ip']));
		$this->status			=	htmlentities(stripslashes($row['entry_status']));
		$this->statusDate		=	htmlentities(stripslashes($row['entry_status_date']));
		$this->note				=	htmlentities(stripslashes($row['entry_note']));
		$this->projectId		=	htmlentities(stripslashes($row['entry_fk_project_id']));
		$this->userId			=	htmlentities(stripslashes($row['entry_fk_user_id']));
		$this->taskId			=	htmlentities(stripslashes($row['entry_fk_task_id']));
	}
}


###################################################################################################
###   USER   ######################################################################################


define('USER_STATUS_ACTIVE',	1);
define('USER_STATUS_INACTIVE',	0);

define('USER_LEVEL_USER',		1); // Regular user
define('USER_LEVEL_ADMIN',		2);	// Projects managers
define('USER_LEVEL_SUPERADMIN',	3); // The master (company admin)

class User extends Entity {
	public $name;
	public $email;
	public $password;
	public $date;
	public $status;
	public $level;
	public $defaultProject;
	public $defaultTask;

	function loadFromSQL($row) {
		$this->id				=	htmlentities(stripslashes($row['user_id']));
		$this->name				=	htmlentities(stripslashes($row['user_name']));
		$this->email			=	htmlentities(stripslashes($row['user_email']));
		$this->password			=	htmlentities(stripslashes($row['user_password']));
		$this->date				=	htmlentities(stripslashes($row['user_createdate']));
		$this->status			=	htmlentities(stripslashes($row['user_status']));
		$this->level			=	htmlentities(stripslashes($row['user_level']));
		$this->defaultProject	=	htmlentities(stripslashes($row['user_fk_defaultproject']));
		$this->defaultTask		=	htmlentities(stripslashes($row['user_fk_defaulttask']));
	}
}


###################################################################################################
###   USER IN PROJECT   ###########################################################################

class UserInProject {
	public $userId;
	public $projectId;
	
	function loadFromSQL($row) {
		$this->userId			=	htmlentities(stripslashes($row['userinproject_fk_user_id']));
		$this->projectId		=	htmlentities(stripslashes($row['userinproject_fk_project_id']));
	}
}

###################################################################################################
###   CLIENT   ####################################################################################


class Client extends Entity {
	public $name;
	public $createDate;
	
	function loadFromSQL($row) {
		$this->id				=	htmlentities(stripslashes($row['client_id']));
		$this->name				=	htmlentities(stripslashes($row['client_name']));
		$this->createDate		=	htmlentities(stripslashes($row['client_createdate']));
	}
}


###################################################################################################
###   PROJECT   ###################################################################################


define('PROJECT_STATUS_OPEN',	1);
define('PROJECT_STATUS_CLOSE',	0);

class Project extends Entity {
	public $name;
	public $createDate;
	public $status;
	public $clientId;
	
	function loadFromSQL($row) {
		$this->id				=	htmlentities(stripslashes($row['project_id']));
		$this->name				=	htmlentities(stripslashes($row['project_name']));
		$this->createDate		=	htmlentities(stripslashes($row['project_createdate']));
		$this->status			=	htmlentities(stripslashes($row['project_status']));
		$this->clientId			=	htmlentities(stripslashes($row['project_fk_client_id']));
	}
}


###################################################################################################
###   TASK   ######################################################################################


class Task extends Entity {
	public $name;
	public $createDate;
	public $order;
	public $projectId;
	
	function loadFromSQL($row) {
		$this->id				=	htmlentities(stripslashes($row['task_id']));
		$this->name				=	htmlentities(stripslashes($row['task_name']));
		$this->createDate		=	htmlentities(stripslashes($row['task_createdate']));
		$this->order			=	htmlentities(stripslashes($row['task_order']));
		$this->projectId		=	htmlentities(stripslashes($row['task_fk_project_id']));
	}
}


###################################################################################################
###   TASK   ######################################################################################


class Settings {
	public $key;
	public $value;
	
	function loadFromSQL($row) {
		$this->key				=	htmlentities(stripslashes($row['settings_key']));
		$this->value			=	htmlentities(stripslashes($row['settings_value']));
	}
}


###################################################################################################
###   REPORTS  ####################################################################################



/**
 * General reports
 * 
 * @author	Liviu
 * @since 	Apr 25, 2008
 */
class GeneralReports {
	public $startDate;
	public $endDate;
}



/**
 * Employees reports
 * 
 * @author	Liviu
 * @since 	Apr 25, 2008
 */
class EmployeesReports {
	public $userId;
	public $projectId;
	public $periodOfTime;
	public $startDate;
	public $endDate;
}



/**
 * Project reports
 * 
 * @author	Liviu
 * @since 	Apr 25, 2008
 */
class ProjectReports {
	public $projectId;
	public $userId;
	public $startDate;
	public $endDate;
}



/**
 * Client reports
 * 
 * @author	Liviu
 * @since 	Apr 25, 2008
 */
class ClientReports {
	public $clientId;
	public $projectId;
	public $startDate;
	public $endDate;
}
?>